@@ -35,7 +35,7 @@ EVAL_COMMAND_NAME = 'ep2_eval'
 KEY_UE_NO = 'ue'
 KEY_UE_TAG = 'tag'
 
-__version__ = '0.4.17'
+__version__ = '0.4.18'
 
 def relative_path(basedir, filename):
     """Creates a path relative to base"""
@@ -486,7 +486,7 @@ class Ep2:
                     exit(5)
 
     def local_ta_repository(self, team: str):
-        return os.path.join(self.uebung_dir(), "ta_" + team)
+        return os.path.join(self.uebung_dir(), team.lower())
 
     def local_team_repository(self, team: str):
         return os.path.join(self.uebung_dir(), team)
