@@ -637,35 +637,52 @@ def checkout(ctx, group, ue: int):
     checkout_info: [ExTestCheckoutInfo] = []
 
     with open(csv_path, 'r') as csvfile:
-        reader = csv.DictReader(csvfile, ex_test_csv_fieldnames(), KEY_INVALID, strict=True)
+        if ue_type(ue) == ExerciseType.Normal:
+            reader = csv.DictReader(csvfile, ex_test_csv_fieldnames(), KEY_INVALID, strict=True)
 
-        headers = next(reader, None)
-        if not validate_headers(headers):
-            click.secho('Malformed file: %s. Invalid headers!' % csv_path)
-            exit(1)
-
-        for row in reader:
-            if KEY_INVALID in row:
-                click.secho('Malformed file: %s' % csv_path, fg='red')
+            headers = next(reader, None)
+            if not validate_headers(headers):
+                click.secho('Malformed file: %s. Invalid headers!' % csv_path)
                 exit(1)
 
-            if not check_row(row):
-                click.secho('Malformed file: %s. Missing column(s)!' % csv_path, fg='red')
+            for row in reader:
+                if KEY_INVALID in row:
+                    click.secho('Malformed file: %s' % csv_path, fg='red')
+                    exit(1)
+
+                if not check_row(row):
+                    click.secho('Malformed file: %s. Missing column(s)!' % csv_path, fg='red')
+                    exit(1)
+
+                teams.add(row[KEY_EX_TEST_TEAM])
+
+                if row[KEY_EX_TEST_ROLE] == 'o':
+                    student_id = verify_and_normalize_student_id(row[KEY_STUDENT_ID])
+
+                    if student_id.is_err():
+                        click.secho("[ERROR] unrecoverable error in student id normalization: {}".format(student_id.err()),
+                                    fg='red', bold=True)
+                        return
+                    else:
+                        student_id = student_id.ok()
+
+                    checkout_info += [ExTestCheckoutInfo(student_id, row[KEY_EX_TEST_TEAM])]
+        else:
+            reader = csv.DictReader(csvfile, ex_test_ta_csv_fieldnames(), KEY_INVALID, strict=True)
+
+            headers = next(reader, None)
+            if not validate_headers(headers):
+                click.secho('Malformed file: %s. Invalid headers!' % csv_path)
                 exit(1)
 
-            teams.add(row[KEY_EX_TEST_TEAM])
+            for row in reader:
+                if KEY_INVALID in row:
+                    click.secho('Malformed file: %s' % csv_path, fg='red')
+                    exit(1)
 
-            if row[KEY_EX_TEST_ROLE] == 'o':
-                student_id = verify_and_normalize_student_id(row[KEY_STUDENT_ID])
+                teams.add(row[KEY_EX_TEST_TEAM])
 
-                if student_id.is_err():
-                    click.secho("[ERROR] unrecoverable error in student id normalization: {}".format(student_id.err()),
-                                fg='red', bold=True)
-                    return
-                else:
-                    student_id = student_id.ok()
-
-                checkout_info += [ExTestCheckoutInfo(student_id, row[KEY_EX_TEST_TEAM])]
+                checkout_info += [ExTestCheckoutInfo(row[KEY_EX_TEST_TEAM], row[KEY_EX_TEST_TEAM])]
 
     teams_without_repo = list(filter(lambda team: all(chkout.team != team for chkout in checkout_info), teams))
     if len(teams_without_repo) > 0:
